SWDEV-1 - Fix warnings and update disabled test list (#163)
- Fix warnings in some test cases due to unused variables or signed/unsigned comparison. - Disabled vulkan tests on MI200.
Этот коммит содержится в:
коммит произвёл
GitHub
родитель
554ab5dc40
Коммит
88fbbd666b
@@ -148,10 +148,10 @@ TEST_CASE("Unit_hipMemAdvise_Rounding") {
|
||||
unsigned int attribute = 0;
|
||||
HIP_CHECK(hipMemRangeGetAttribute(&attribute, sizeof(attribute), hipMemRangeAttributeAccessedBy,
|
||||
reinterpret_cast<void*>(base), rounded_up));
|
||||
REQUIRE(device == attribute);
|
||||
REQUIRE(device == static_cast<int>(attribute));
|
||||
HIP_CHECK(hipMemRangeGetAttribute(&attribute, sizeof(attribute), hipMemRangeAttributeAccessedBy,
|
||||
alloc.ptr(), 3 * kPageSize));
|
||||
REQUIRE((rounded_up == 3 * kPageSize ? device : hipInvalidDeviceId) == attribute);
|
||||
REQUIRE((rounded_up == 3 * kPageSize ? device : hipInvalidDeviceId) == static_cast<int>(attribute));
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipMemAdvise_Flags_Do_Not_Cause_Prefetch") {
|
||||
@@ -193,7 +193,7 @@ TEST_CASE("Unit_hipMemAdvise_Read_Write_After_Advise") {
|
||||
|
||||
std::fill_n(alloc.ptr(), count, -1);
|
||||
ArrayFindIfNot(alloc.ptr(), -1, count);
|
||||
for (int i = 0; i < supported_devices.size(); ++i) {
|
||||
for (int i = 0; i < static_cast<int>(supported_devices.size()); ++i) {
|
||||
HIP_CHECK(hipSetDevice(supported_devices[i]));
|
||||
VectorIncrement<<<count / 1024 + 1, 1024>>>(alloc.ptr(), 1, count);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
|
||||
@@ -213,12 +213,10 @@ TEST_CASE("Unit_hipPointerGetAttributes_Basic") {
|
||||
|
||||
char* A_d;
|
||||
char* A_Pinned_h;
|
||||
char* A_OSAlloc_h;
|
||||
hipError_t e;
|
||||
|
||||
HIP_CHECK(hipMalloc(&A_d, Nbytes));
|
||||
HIP_CHECK(hipHostMalloc(reinterpret_cast<void**>(&A_Pinned_h), Nbytes, hipHostMallocDefault));
|
||||
A_OSAlloc_h = reinterpret_cast<char*>(malloc(Nbytes));
|
||||
|
||||
size_t free, total;
|
||||
HIP_CHECK(hipMemGetInfo(&free, &total));
|
||||
|
||||
Ссылка в новой задаче
Block a user